@@ -1,4 +1,3 @@
-use crate::checkout::Checkout;
 use crate::context::Context;
 use crate::error::{new_not_found_error, Error};
 use crate::internal_context::InternalContext;
@@ -75,15 +74,11 @@ pub async fn callback_handler<C: Context + Send>(
     Ok(payment)
 }
 
-pub async fn process_handler<C: Context + Send>(ctx: &mut C, id: String) -> Result<(), Error> {
-    let maybe_checkout = get_associated_checkout_for_update(ctx, &id).await?;
-    if maybe_checkout.is_none() {
-        // this isn't supposed to happen. maybe log the error and move on
-        return Ok(());
-    }
-
-    let mut checkout = maybe_checkout.unwrap();
-
+pub async fn process_handler<C: Context + Send>(
+    internal_ctx: &InternalContext,
+    ctx: &mut C,
+    id: String,
+) -> Result<(), Error> {
     let maybe_payment = ctx.get_payment_for_update(&id).await?;
     if maybe_payment.is_none() {
         // this isn't supposed to happen. maybe log the error and move on
@@ -92,7 +87,15 @@ pub async fn process_handler<C: Context + Send>(ctx: &mut C, id: String) -> Resu
 
     let mut payment = maybe_payment.unwrap();
 
-    process(ctx, &mut payment, &mut checkout).await?;
+    let maybe_checkout = ctx.get_checkout_for_update(&payment.checkout_id).await?;
+    if maybe_checkout.is_none() {
+        // this isn't supposed to happen. maybe log the error and move on
+        return Ok(());
+    }
+
+    let mut checkout = maybe_checkout.unwrap();
+
+    process(internal_ctx, ctx, &mut payment, &mut checkout).await?;
 
     Ok(())
 }
@@ -115,22 +118,16 @@ pub async fn cancel_handler<C: Context + Send>(
     }
     let mut payment = maybe_payment.unwrap();
 
-    cancel(ctx, &mut payment).await?;
+    let maybe_checkout = ctx.get_checkout_for_update(&payment.checkout_id).await?;
+    if maybe_checkout.is_none() {
+        return Err(new_not_found_error(
+            "the associated checkout could not be found",
+        ));
+    }
+
+    let mut checkout = maybe_checkout.unwrap();
+
+    cancel(ctx, &mut payment, &mut checkout).await?;
 
     Ok(payment)
 }
-
-async fn get_associated_checkout_for_update<C: Context + Send>(
-    ctx: &mut C,
-    payment_id: &str,
-) -> Result<Option<Checkout>, Error> {
-    let maybe_payment = ctx.get_payment(payment_id).await?;
-    if maybe_payment.is_none() {
-        return Ok(None);
-    }
-
-    let maybe_checkout = ctx
-        .get_checkout_for_update(&maybe_payment.unwrap().checkout_id)
-        .await?;
-    Ok(maybe_checkout)
-}
