@@ -60,7 +60,7 @@ pub trait PaymentProcessor {
     ) -> Result<ProcessingResult<Self::CorrelationID, Self::PrivateData, Self::PublicData>, Error>;
 
     // this is called synchronously and only once per revert request
-    async fn revert(
+    async fn cancel_payment(
         &mut self,
         payment: &Payment<
             Self::CorrelationID,
@@ -299,7 +299,7 @@ pub async fn cancel<C: Context + Send>(
     match &payment.state {
         PaymentState::Cancelled => Ok(()),
         PaymentState::Idle => {
-            let cancellation_result = ctx.revert(payment).await?;
+            let cancellation_result = ctx.cancel_payment(payment).await?;
             if !cancellation_result.success {
                 return Err(new_application_error(
                     "CANCELLATION_UNAVAILABLE",
